/* Generated automatically by the program `gencodes'
   from the machine description file `md'.  */

#ifndef GCC_INSN_CODES_H
#define GCC_INSN_CODES_H

enum insn_code {
  CODE_FOR_nothing = 0,
  CODE_FOR_pushqi1 = 1,
  CODE_FOR_pushqq1 = 2,
  CODE_FOR_pushuqq1 = 3,
  CODE_FOR_pushhi1_insn = 4,
  CODE_FOR_load_qi_libgcc = 5,
  CODE_FOR_load_qq_libgcc = 6,
  CODE_FOR_load_uqq_libgcc = 7,
  CODE_FOR_load_hi_libgcc = 8,
  CODE_FOR_load_hq_libgcc = 9,
  CODE_FOR_load_uhq_libgcc = 10,
  CODE_FOR_load_ha_libgcc = 11,
  CODE_FOR_load_uha_libgcc = 12,
  CODE_FOR_load_si_libgcc = 13,
  CODE_FOR_load_sq_libgcc = 14,
  CODE_FOR_load_usq_libgcc = 15,
  CODE_FOR_load_sa_libgcc = 16,
  CODE_FOR_load_usa_libgcc = 17,
  CODE_FOR_load_sf_libgcc = 18,
  CODE_FOR_load_psi_libgcc = 19,
  CODE_FOR_xload8qi_A = 35,
  CODE_FOR_xload8qq_A = 36,
  CODE_FOR_xload8uqq_A = 37,
  CODE_FOR_xloadqi_A = 38,
  CODE_FOR_xloadqq_A = 39,
  CODE_FOR_xloaduqq_A = 40,
  CODE_FOR_xloadhi_A = 41,
  CODE_FOR_xloadhq_A = 42,
  CODE_FOR_xloaduhq_A = 43,
  CODE_FOR_xloadha_A = 44,
  CODE_FOR_xloaduha_A = 45,
  CODE_FOR_xloadsi_A = 46,
  CODE_FOR_xloadsq_A = 47,
  CODE_FOR_xloadusq_A = 48,
  CODE_FOR_xloadsa_A = 49,
  CODE_FOR_xloadusa_A = 50,
  CODE_FOR_xloadsf_A = 51,
  CODE_FOR_xloadpsi_A = 52,
  CODE_FOR_xloadqi_8 = 53,
  CODE_FOR_xloadqq_8 = 54,
  CODE_FOR_xloaduqq_8 = 55,
  CODE_FOR_xload_qi_libgcc = 56,
  CODE_FOR_xload_qq_libgcc = 57,
  CODE_FOR_xload_uqq_libgcc = 58,
  CODE_FOR_xload_hi_libgcc = 59,
  CODE_FOR_xload_hq_libgcc = 60,
  CODE_FOR_xload_uhq_libgcc = 61,
  CODE_FOR_xload_ha_libgcc = 62,
  CODE_FOR_xload_uha_libgcc = 63,
  CODE_FOR_xload_si_libgcc = 64,
  CODE_FOR_xload_sq_libgcc = 65,
  CODE_FOR_xload_usq_libgcc = 66,
  CODE_FOR_xload_sa_libgcc = 67,
  CODE_FOR_xload_usa_libgcc = 68,
  CODE_FOR_xload_sf_libgcc = 69,
  CODE_FOR_xload_psi_libgcc = 70,
  CODE_FOR_movqi_insn_split = 86,
  CODE_FOR_movqq_insn_split = 87,
  CODE_FOR_movuqq_insn_split = 88,
  CODE_FOR_movqi_insn = 89,
  CODE_FOR_movqq_insn = 90,
  CODE_FOR_movuqq_insn = 91,
  CODE_FOR_movhi_sp_r = 95,
  CODE_FOR_cpymem_qi = 132,
  CODE_FOR_cpymem_hi = 133,
  CODE_FOR_cpymemx_qi = 136,
  CODE_FOR_cpymemx_hi = 137,
  CODE_FOR_addqi3 = 146,
  CODE_FOR_addqq3 = 147,
  CODE_FOR_adduqq3 = 148,
  CODE_FOR_addhi3_clobber = 175,
  CODE_FOR_addhq3_clobber = 176,
  CODE_FOR_adduhq3_clobber = 177,
  CODE_FOR_addha3_clobber = 178,
  CODE_FOR_adduha3_clobber = 179,
  CODE_FOR_addsi3 = 185,
  CODE_FOR_addsq3 = 186,
  CODE_FOR_addusq3 = 187,
  CODE_FOR_addsa3 = 188,
  CODE_FOR_addusa3 = 189,
  CODE_FOR_addpsi3 = 205,
  CODE_FOR_subpsi3 = 207,
  CODE_FOR_subqi3 = 215,
  CODE_FOR_subqq3 = 216,
  CODE_FOR_subuqq3 = 217,
  CODE_FOR_subhi3 = 221,
  CODE_FOR_subhq3 = 222,
  CODE_FOR_subuhq3 = 223,
  CODE_FOR_subha3 = 224,
  CODE_FOR_subuha3 = 225,
  CODE_FOR_subsi3 = 235,
  CODE_FOR_subsq3 = 236,
  CODE_FOR_subusq3 = 237,
  CODE_FOR_subsa3 = 238,
  CODE_FOR_subusa3 = 239,
  CODE_FOR_smulqi3_highpart = 253,
  CODE_FOR_umulqi3_highpart = 254,
  CODE_FOR_mulqihi3_split = 269,
  CODE_FOR_umulqihi3_split = 270,
  CODE_FOR_mulqihi3 = 271,
  CODE_FOR_umulqihi3 = 272,
  CODE_FOR_usmulqihi3 = 273,
  CODE_FOR_mulsqihi3 = 322,
  CODE_FOR_muluqihi3 = 324,
  CODE_FOR_muloqihi3 = 326,
  CODE_FOR_divmodqi4 = 372,
  CODE_FOR_udivmodqi4 = 375,
  CODE_FOR_divmodhi4 = 378,
  CODE_FOR_udivmodhi4 = 381,
  CODE_FOR_divmodpsi4 = 394,
  CODE_FOR_udivmodpsi4 = 397,
  CODE_FOR_divmodsi4 = 400,
  CODE_FOR_udivmodsi4 = 403,
  CODE_FOR_andqi3 = 406,
  CODE_FOR_andhi3 = 408,
  CODE_FOR_andpsi3 = 410,
  CODE_FOR_andsi3 = 412,
  CODE_FOR_iorqi3 = 414,
  CODE_FOR_iorhi3 = 416,
  CODE_FOR_iorpsi3 = 418,
  CODE_FOR_iorsi3 = 420,
  CODE_FOR_xorqi3 = 422,
  CODE_FOR_xorhi3 = 424,
  CODE_FOR_xorpsi3 = 426,
  CODE_FOR_xorsi3 = 428,
  CODE_FOR_ashlhi3 = 456,
  CODE_FOR_ashlhq3 = 457,
  CODE_FOR_ashluhq3 = 458,
  CODE_FOR_ashlha3 = 459,
  CODE_FOR_ashluha3 = 460,
  CODE_FOR_ashlsi3 = 471,
  CODE_FOR_ashlsq3 = 472,
  CODE_FOR_ashlusq3 = 473,
  CODE_FOR_ashlsa3 = 474,
  CODE_FOR_ashlusa3 = 475,
  CODE_FOR_ashrqi3 = 503,
  CODE_FOR_ashrqq3 = 504,
  CODE_FOR_ashruqq3 = 505,
  CODE_FOR_ashrhi3 = 509,
  CODE_FOR_ashrhq3 = 510,
  CODE_FOR_ashruhq3 = 511,
  CODE_FOR_ashrha3 = 512,
  CODE_FOR_ashruha3 = 513,
  CODE_FOR_ashrpsi3 = 519,
  CODE_FOR_ashrsi3 = 521,
  CODE_FOR_ashrsq3 = 522,
  CODE_FOR_ashrusq3 = 523,
  CODE_FOR_ashrsa3 = 524,
  CODE_FOR_ashrusa3 = 525,
  CODE_FOR_lshrhi3 = 557,
  CODE_FOR_lshrhq3 = 558,
  CODE_FOR_lshruhq3 = 559,
  CODE_FOR_lshrha3 = 560,
  CODE_FOR_lshruha3 = 561,
  CODE_FOR_lshrpsi3 = 567,
  CODE_FOR_lshrsi3 = 569,
  CODE_FOR_lshrsq3 = 570,
  CODE_FOR_lshrusq3 = 571,
  CODE_FOR_lshrsa3 = 572,
  CODE_FOR_lshrusa3 = 573,
  CODE_FOR_absqi2 = 599,
  CODE_FOR_abssf2 = 601,
  CODE_FOR_negqi2 = 603,
  CODE_FOR_neghi2 = 607,
  CODE_FOR_negpsi2 = 609,
  CODE_FOR_negsi2 = 611,
  CODE_FOR_negsf2 = 613,
  CODE_FOR_one_cmplqi2 = 615,
  CODE_FOR_one_cmplhi2 = 617,
  CODE_FOR_one_cmplpsi2 = 619,
  CODE_FOR_one_cmplsi2 = 621,
  CODE_FOR_extendqihi2 = 623,
  CODE_FOR_extendqipsi2 = 625,
  CODE_FOR_extendqisi2 = 627,
  CODE_FOR_extendhipsi2 = 629,
  CODE_FOR_extendhisi2 = 631,
  CODE_FOR_extendpsisi2 = 633,
  CODE_FOR_zero_extendqihi2 = 635,
  CODE_FOR_zero_extendqipsi2 = 636,
  CODE_FOR_zero_extendqisi2 = 637,
  CODE_FOR_zero_extendhipsi2 = 638,
  CODE_FOR_n_extendhipsi2 = 639,
  CODE_FOR_zero_extendhisi2 = 640,
  CODE_FOR_zero_extendpsisi2 = 641,
  CODE_FOR_zero_extendqidi2 = 642,
  CODE_FOR_zero_extendhidi2 = 643,
  CODE_FOR_zero_extendsidi2 = 644,
  CODE_FOR_cmpqi3 = 654,
  CODE_FOR_cmpqq3 = 655,
  CODE_FOR_cmpuqq3 = 656,
  CODE_FOR_cmphi3 = 693,
  CODE_FOR_cmphq3 = 694,
  CODE_FOR_cmpuhq3 = 695,
  CODE_FOR_cmpha3 = 696,
  CODE_FOR_cmpuha3 = 697,
  CODE_FOR_cbranchqi4_insn = 704,
  CODE_FOR_cbranchqq4_insn = 705,
  CODE_FOR_cbranchuqq4_insn = 706,
  CODE_FOR_cbranchsi4_insn = 707,
  CODE_FOR_cbranchsq4_insn = 708,
  CODE_FOR_cbranchusq4_insn = 709,
  CODE_FOR_cbranchsa4_insn = 710,
  CODE_FOR_cbranchusa4_insn = 711,
  CODE_FOR_cbranchpsi4_insn = 712,
  CODE_FOR_cbranchhi4_insn = 713,
  CODE_FOR_cbranchhq4_insn = 714,
  CODE_FOR_cbranchuhq4_insn = 715,
  CODE_FOR_cbranchha4_insn = 716,
  CODE_FOR_cbranchuha4_insn = 717,
  CODE_FOR_branch = 772,
  CODE_FOR_difficult_branch = 773,
  CODE_FOR_jump = 774,
  CODE_FOR_call_insn = 775,
  CODE_FOR_call_value_insn = 776,
  CODE_FOR_nop = 777,
  CODE_FOR_casesi_qi_sequence = 783,
  CODE_FOR_casesi_hi_sequence = 784,
  CODE_FOR_popqi = 799,
  CODE_FOR_cli_sei = 800,
  CODE_FOR_call_prologue_saves = 801,
  CODE_FOR_epilogue_restores = 802,
  CODE_FOR_return = 804,
  CODE_FOR_return_from_epilogue = 805,
  CODE_FOR_return_from_interrupt_epilogue = 806,
  CODE_FOR_return_from_naked_epilogue = 807,
  CODE_FOR_delay_cycles_1 = 808,
  CODE_FOR_delay_cycles_2 = 810,
  CODE_FOR_delay_cycles_3 = 812,
  CODE_FOR_delay_cycles_4 = 814,
  CODE_FOR_insert_bits = 816,
  CODE_FOR_copysignsf3 = 847,
  CODE_FOR_fmul_insn = 853,
  CODE_FOR_fmuls_insn = 857,
  CODE_FOR_fmulsu_insn = 861,
   CODE_FOR_fractqqqq2 = CODE_FOR_nothing,
  CODE_FOR_fractuqqqq2 = 925,
  CODE_FOR_fracthqqq2 = 926,
  CODE_FOR_fractuhqqq2 = 927,
  CODE_FOR_fracthaqq2 = 928,
  CODE_FOR_fractuhaqq2 = 929,
  CODE_FOR_fractsqqq2 = 930,
  CODE_FOR_fractusqqq2 = 931,
  CODE_FOR_fractsaqq2 = 932,
  CODE_FOR_fractusaqq2 = 933,
  CODE_FOR_fractdqqq2 = 934,
  CODE_FOR_fractudqqq2 = 935,
  CODE_FOR_fractdaqq2 = 936,
  CODE_FOR_fractudaqq2 = 937,
  CODE_FOR_fracttaqq2 = 938,
  CODE_FOR_fractutaqq2 = 939,
  CODE_FOR_fractqiqq2 = 940,
  CODE_FOR_fracthiqq2 = 941,
  CODE_FOR_fractsiqq2 = 942,
  CODE_FOR_fractdiqq2 = 943,
  CODE_FOR_fractqquqq2 = 944,
   CODE_FOR_fractuqquqq2 = CODE_FOR_nothing,
  CODE_FOR_fracthquqq2 = 945,
  CODE_FOR_fractuhquqq2 = 946,
  CODE_FOR_fracthauqq2 = 947,
  CODE_FOR_fractuhauqq2 = 948,
  CODE_FOR_fractsquqq2 = 949,
  CODE_FOR_fractusquqq2 = 950,
  CODE_FOR_fractsauqq2 = 951,
  CODE_FOR_fractusauqq2 = 952,
  CODE_FOR_fractdquqq2 = 953,
  CODE_FOR_fractudquqq2 = 954,
  CODE_FOR_fractdauqq2 = 955,
  CODE_FOR_fractudauqq2 = 956,
  CODE_FOR_fracttauqq2 = 957,
  CODE_FOR_fractutauqq2 = 958,
  CODE_FOR_fractqiuqq2 = 959,
  CODE_FOR_fracthiuqq2 = 960,
  CODE_FOR_fractsiuqq2 = 961,
  CODE_FOR_fractdiuqq2 = 962,
  CODE_FOR_fractqqhq2 = 963,
  CODE_FOR_fractuqqhq2 = 964,
   CODE_FOR_fracthqhq2 = CODE_FOR_nothing,
  CODE_FOR_fractuhqhq2 = 965,
  CODE_FOR_fracthahq2 = 966,
  CODE_FOR_fractuhahq2 = 967,
  CODE_FOR_fractsqhq2 = 968,
  CODE_FOR_fractusqhq2 = 969,
  CODE_FOR_fractsahq2 = 970,
  CODE_FOR_fractusahq2 = 971,
  CODE_FOR_fractdqhq2 = 972,
  CODE_FOR_fractudqhq2 = 973,
  CODE_FOR_fractdahq2 = 974,
  CODE_FOR_fractudahq2 = 975,
  CODE_FOR_fracttahq2 = 976,
  CODE_FOR_fractutahq2 = 977,
  CODE_FOR_fractqihq2 = 978,
  CODE_FOR_fracthihq2 = 979,
  CODE_FOR_fractsihq2 = 980,
  CODE_FOR_fractdihq2 = 981,
  CODE_FOR_fractqquhq2 = 982,
  CODE_FOR_fractuqquhq2 = 983,
  CODE_FOR_fracthquhq2 = 984,
   CODE_FOR_fractuhquhq2 = CODE_FOR_nothing,
  CODE_FOR_fracthauhq2 = 985,
  CODE_FOR_fractuhauhq2 = 986,
  CODE_FOR_fractsquhq2 = 987,
  CODE_FOR_fractusquhq2 = 988,
  CODE_FOR_fractsauhq2 = 989,
  CODE_FOR_fractusauhq2 = 990,
  CODE_FOR_fractdquhq2 = 991,
  CODE_FOR_fractudquhq2 = 992,
  CODE_FOR_fractdauhq2 = 993,
  CODE_FOR_fractudauhq2 = 994,
  CODE_FOR_fracttauhq2 = 995,
  CODE_FOR_fractutauhq2 = 996,
  CODE_FOR_fractqiuhq2 = 997,
  CODE_FOR_fracthiuhq2 = 998,
  CODE_FOR_fractsiuhq2 = 999,
  CODE_FOR_fractdiuhq2 = 1000,
  CODE_FOR_fractqqha2 = 1001,
  CODE_FOR_fractuqqha2 = 1002,
  CODE_FOR_fracthqha2 = 1003,
  CODE_FOR_fractuhqha2 = 1004,
   CODE_FOR_fracthaha2 = CODE_FOR_nothing,
  CODE_FOR_fractuhaha2 = 1005,
  CODE_FOR_fractsqha2 = 1006,
  CODE_FOR_fractusqha2 = 1007,
  CODE_FOR_fractsaha2 = 1008,
  CODE_FOR_fractusaha2 = 1009,
  CODE_FOR_fractdqha2 = 1010,
  CODE_FOR_fractudqha2 = 1011,
  CODE_FOR_fractdaha2 = 1012,
  CODE_FOR_fractudaha2 = 1013,
  CODE_FOR_fracttaha2 = 1014,
  CODE_FOR_fractutaha2 = 1015,
  CODE_FOR_fractqiha2 = 1016,
  CODE_FOR_fracthiha2 = 1017,
  CODE_FOR_fractsiha2 = 1018,
  CODE_FOR_fractdiha2 = 1019,
  CODE_FOR_fractqquha2 = 1020,
  CODE_FOR_fractuqquha2 = 1021,
  CODE_FOR_fracthquha2 = 1022,
  CODE_FOR_fractuhquha2 = 1023,
  CODE_FOR_fracthauha2 = 1024,
   CODE_FOR_fractuhauha2 = CODE_FOR_nothing,
  CODE_FOR_fractsquha2 = 1025,
  CODE_FOR_fractusquha2 = 1026,
  CODE_FOR_fractsauha2 = 1027,
  CODE_FOR_fractusauha2 = 1028,
  CODE_FOR_fractdquha2 = 1029,
  CODE_FOR_fractudquha2 = 1030,
  CODE_FOR_fractdauha2 = 1031,
  CODE_FOR_fractudauha2 = 1032,
  CODE_FOR_fracttauha2 = 1033,
  CODE_FOR_fractutauha2 = 1034,
  CODE_FOR_fractqiuha2 = 1035,
  CODE_FOR_fracthiuha2 = 1036,
  CODE_FOR_fractsiuha2 = 1037,
  CODE_FOR_fractdiuha2 = 1038,
  CODE_FOR_fractqqsq2 = 1039,
  CODE_FOR_fractuqqsq2 = 1040,
  CODE_FOR_fracthqsq2 = 1041,
  CODE_FOR_fractuhqsq2 = 1042,
  CODE_FOR_fracthasq2 = 1043,
  CODE_FOR_fractuhasq2 = 1044,
   CODE_FOR_fractsqsq2 = CODE_FOR_nothing,
  CODE_FOR_fractusqsq2 = 1045,
  CODE_FOR_fractsasq2 = 1046,
  CODE_FOR_fractusasq2 = 1047,
  CODE_FOR_fractdqsq2 = 1048,
  CODE_FOR_fractudqsq2 = 1049,
  CODE_FOR_fractdasq2 = 1050,
  CODE_FOR_fractudasq2 = 1051,
  CODE_FOR_fracttasq2 = 1052,
  CODE_FOR_fractutasq2 = 1053,
  CODE_FOR_fractqisq2 = 1054,
  CODE_FOR_fracthisq2 = 1055,
  CODE_FOR_fractsisq2 = 1056,
  CODE_FOR_fractdisq2 = 1057,
  CODE_FOR_fractqqusq2 = 1058,
  CODE_FOR_fractuqqusq2 = 1059,
  CODE_FOR_fracthqusq2 = 1060,
  CODE_FOR_fractuhqusq2 = 1061,
  CODE_FOR_fracthausq2 = 1062,
  CODE_FOR_fractuhausq2 = 1063,
  CODE_FOR_fractsqusq2 = 1064,
   CODE_FOR_fractusqusq2 = CODE_FOR_nothing,
  CODE_FOR_fractsausq2 = 1065,
  CODE_FOR_fractusausq2 = 1066,
  CODE_FOR_fractdqusq2 = 1067,
  CODE_FOR_fractudqusq2 = 1068,
  CODE_FOR_fractdausq2 = 1069,
  CODE_FOR_fractudausq2 = 1070,
  CODE_FOR_fracttausq2 = 1071,
  CODE_FOR_fractutausq2 = 1072,
  CODE_FOR_fractqiusq2 = 1073,
  CODE_FOR_fracthiusq2 = 1074,
  CODE_FOR_fractsiusq2 = 1075,
  CODE_FOR_fractdiusq2 = 1076,
  CODE_FOR_fractqqsa2 = 1077,
  CODE_FOR_fractuqqsa2 = 1078,
  CODE_FOR_fracthqsa2 = 1079,
  CODE_FOR_fractuhqsa2 = 1080,
  CODE_FOR_fracthasa2 = 1081,
  CODE_FOR_fractuhasa2 = 1082,
  CODE_FOR_fractsqsa2 = 1083,
  CODE_FOR_fractusqsa2 = 1084,
   CODE_FOR_fractsasa2 = CODE_FOR_nothing,
  CODE_FOR_fractusasa2 = 1085,
  CODE_FOR_fractdqsa2 = 1086,
  CODE_FOR_fractudqsa2 = 1087,
  CODE_FOR_fractdasa2 = 1088,
  CODE_FOR_fractudasa2 = 1089,
  CODE_FOR_fracttasa2 = 1090,
  CODE_FOR_fractutasa2 = 1091,
  CODE_FOR_fractqisa2 = 1092,
  CODE_FOR_fracthisa2 = 1093,
  CODE_FOR_fractsisa2 = 1094,
  CODE_FOR_fractdisa2 = 1095,
  CODE_FOR_fractqqusa2 = 1096,
  CODE_FOR_fractuqqusa2 = 1097,
  CODE_FOR_fracthqusa2 = 1098,
  CODE_FOR_fractuhqusa2 = 1099,
  CODE_FOR_fracthausa2 = 1100,
  CODE_FOR_fractuhausa2 = 1101,
  CODE_FOR_fractsqusa2 = 1102,
  CODE_FOR_fractusqusa2 = 1103,
  CODE_FOR_fractsausa2 = 1104,
   CODE_FOR_fractusausa2 = CODE_FOR_nothing,
  CODE_FOR_fractdqusa2 = 1105,
  CODE_FOR_fractudqusa2 = 1106,
  CODE_FOR_fractdausa2 = 1107,
  CODE_FOR_fractudausa2 = 1108,
  CODE_FOR_fracttausa2 = 1109,
  CODE_FOR_fractutausa2 = 1110,
  CODE_FOR_fractqiusa2 = 1111,
  CODE_FOR_fracthiusa2 = 1112,
  CODE_FOR_fractsiusa2 = 1113,
  CODE_FOR_fractdiusa2 = 1114,
  CODE_FOR_fractqqdq2 = 1115,
  CODE_FOR_fractuqqdq2 = 1116,
  CODE_FOR_fracthqdq2 = 1117,
  CODE_FOR_fractuhqdq2 = 1118,
  CODE_FOR_fracthadq2 = 1119,
  CODE_FOR_fractuhadq2 = 1120,
  CODE_FOR_fractsqdq2 = 1121,
  CODE_FOR_fractusqdq2 = 1122,
  CODE_FOR_fractsadq2 = 1123,
  CODE_FOR_fractusadq2 = 1124,
   CODE_FOR_fractdqdq2 = CODE_FOR_nothing,
  CODE_FOR_fractudqdq2 = 1125,
  CODE_FOR_fractdadq2 = 1126,
  CODE_FOR_fractudadq2 = 1127,
  CODE_FOR_fracttadq2 = 1128,
  CODE_FOR_fractutadq2 = 1129,
  CODE_FOR_fractqidq2 = 1130,
  CODE_FOR_fracthidq2 = 1131,
  CODE_FOR_fractsidq2 = 1132,
  CODE_FOR_fractdidq2 = 1133,
  CODE_FOR_fractqqudq2 = 1134,
  CODE_FOR_fractuqqudq2 = 1135,
  CODE_FOR_fracthqudq2 = 1136,
  CODE_FOR_fractuhqudq2 = 1137,
  CODE_FOR_fracthaudq2 = 1138,
  CODE_FOR_fractuhaudq2 = 1139,
  CODE_FOR_fractsqudq2 = 1140,
  CODE_FOR_fractusqudq2 = 1141,
  CODE_FOR_fractsaudq2 = 1142,
  CODE_FOR_fractusaudq2 = 1143,
  CODE_FOR_fractdqudq2 = 1144,
   CODE_FOR_fractudqudq2 = CODE_FOR_nothing,
  CODE_FOR_fractdaudq2 = 1145,
  CODE_FOR_fractudaudq2 = 1146,
  CODE_FOR_fracttaudq2 = 1147,
  CODE_FOR_fractutaudq2 = 1148,
  CODE_FOR_fractqiudq2 = 1149,
  CODE_FOR_fracthiudq2 = 1150,
  CODE_FOR_fractsiudq2 = 1151,
  CODE_FOR_fractdiudq2 = 1152,
  CODE_FOR_fractqqda2 = 1153,
  CODE_FOR_fractuqqda2 = 1154,
  CODE_FOR_fracthqda2 = 1155,
  CODE_FOR_fractuhqda2 = 1156,
  CODE_FOR_fracthada2 = 1157,
  CODE_FOR_fractuhada2 = 1158,
  CODE_FOR_fractsqda2 = 1159,
  CODE_FOR_fractusqda2 = 1160,
  CODE_FOR_fractsada2 = 1161,
  CODE_FOR_fractusada2 = 1162,
  CODE_FOR_fractdqda2 = 1163,
  CODE_FOR_fractudqda2 = 1164,
   CODE_FOR_fractdada2 = CODE_FOR_nothing,
  CODE_FOR_fractudada2 = 1165,
  CODE_FOR_fracttada2 = 1166,
  CODE_FOR_fractutada2 = 1167,
  CODE_FOR_fractqida2 = 1168,
  CODE_FOR_fracthida2 = 1169,
  CODE_FOR_fractsida2 = 1170,
  CODE_FOR_fractdida2 = 1171,
  CODE_FOR_fractqquda2 = 1172,
  CODE_FOR_fractuqquda2 = 1173,
  CODE_FOR_fracthquda2 = 1174,
  CODE_FOR_fractuhquda2 = 1175,
  CODE_FOR_fracthauda2 = 1176,
  CODE_FOR_fractuhauda2 = 1177,
  CODE_FOR_fractsquda2 = 1178,
  CODE_FOR_fractusquda2 = 1179,
  CODE_FOR_fractsauda2 = 1180,
  CODE_FOR_fractusauda2 = 1181,
  CODE_FOR_fractdquda2 = 1182,
  CODE_FOR_fractudquda2 = 1183,
  CODE_FOR_fractdauda2 = 1184,
   CODE_FOR_fractudauda2 = CODE_FOR_nothing,
  CODE_FOR_fracttauda2 = 1185,
  CODE_FOR_fractutauda2 = 1186,
  CODE_FOR_fractqiuda2 = 1187,
  CODE_FOR_fracthiuda2 = 1188,
  CODE_FOR_fractsiuda2 = 1189,
  CODE_FOR_fractdiuda2 = 1190,
  CODE_FOR_fractqqta2 = 1191,
  CODE_FOR_fractuqqta2 = 1192,
  CODE_FOR_fracthqta2 = 1193,
  CODE_FOR_fractuhqta2 = 1194,
  CODE_FOR_fracthata2 = 1195,
  CODE_FOR_fractuhata2 = 1196,
  CODE_FOR_fractsqta2 = 1197,
  CODE_FOR_fractusqta2 = 1198,
  CODE_FOR_fractsata2 = 1199,
  CODE_FOR_fractusata2 = 1200,
  CODE_FOR_fractdqta2 = 1201,
  CODE_FOR_fractudqta2 = 1202,
  CODE_FOR_fractdata2 = 1203,
  CODE_FOR_fractudata2 = 1204,
   CODE_FOR_fracttata2 = CODE_FOR_nothing,
  CODE_FOR_fractutata2 = 1205,
  CODE_FOR_fractqita2 = 1206,
  CODE_FOR_fracthita2 = 1207,
  CODE_FOR_fractsita2 = 1208,
  CODE_FOR_fractdita2 = 1209,
  CODE_FOR_fractqquta2 = 1210,
  CODE_FOR_fractuqquta2 = 1211,
  CODE_FOR_fracthquta2 = 1212,
  CODE_FOR_fractuhquta2 = 1213,
  CODE_FOR_fracthauta2 = 1214,
  CODE_FOR_fractuhauta2 = 1215,
  CODE_FOR_fractsquta2 = 1216,
  CODE_FOR_fractusquta2 = 1217,
  CODE_FOR_fractsauta2 = 1218,
  CODE_FOR_fractusauta2 = 1219,
  CODE_FOR_fractdquta2 = 1220,
  CODE_FOR_fractudquta2 = 1221,
  CODE_FOR_fractdauta2 = 1222,
  CODE_FOR_fractudauta2 = 1223,
  CODE_FOR_fracttauta2 = 1224,
   CODE_FOR_fractutauta2 = CODE_FOR_nothing,
  CODE_FOR_fractqiuta2 = 1225,
  CODE_FOR_fracthiuta2 = 1226,
  CODE_FOR_fractsiuta2 = 1227,
  CODE_FOR_fractdiuta2 = 1228,
  CODE_FOR_fractqqqi2 = 1229,
  CODE_FOR_fractuqqqi2 = 1230,
  CODE_FOR_fracthqqi2 = 1231,
  CODE_FOR_fractuhqqi2 = 1232,
  CODE_FOR_fracthaqi2 = 1233,
  CODE_FOR_fractuhaqi2 = 1234,
  CODE_FOR_fractsqqi2 = 1235,
  CODE_FOR_fractusqqi2 = 1236,
  CODE_FOR_fractsaqi2 = 1237,
  CODE_FOR_fractusaqi2 = 1238,
  CODE_FOR_fractdqqi2 = 1239,
  CODE_FOR_fractudqqi2 = 1240,
  CODE_FOR_fractdaqi2 = 1241,
  CODE_FOR_fractudaqi2 = 1242,
  CODE_FOR_fracttaqi2 = 1243,
  CODE_FOR_fractutaqi2 = 1244,
   CODE_FOR_fractqiqi2 = CODE_FOR_nothing,
  CODE_FOR_fracthiqi2 = 1245,
  CODE_FOR_fractsiqi2 = 1246,
  CODE_FOR_fractdiqi2 = 1247,
  CODE_FOR_fractqqhi2 = 1248,
  CODE_FOR_fractuqqhi2 = 1249,
  CODE_FOR_fracthqhi2 = 1250,
  CODE_FOR_fractuhqhi2 = 1251,
  CODE_FOR_fracthahi2 = 1252,
  CODE_FOR_fractuhahi2 = 1253,
  CODE_FOR_fractsqhi2 = 1254,
  CODE_FOR_fractusqhi2 = 1255,
  CODE_FOR_fractsahi2 = 1256,
  CODE_FOR_fractusahi2 = 1257,
  CODE_FOR_fractdqhi2 = 1258,
  CODE_FOR_fractudqhi2 = 1259,
  CODE_FOR_fractdahi2 = 1260,
  CODE_FOR_fractudahi2 = 1261,
  CODE_FOR_fracttahi2 = 1262,
  CODE_FOR_fractutahi2 = 1263,
  CODE_FOR_fractqihi2 = 1264,
   CODE_FOR_fracthihi2 = CODE_FOR_nothing,
  CODE_FOR_fractsihi2 = 1265,
  CODE_FOR_fractdihi2 = 1266,
  CODE_FOR_fractqqsi2 = 1267,
  CODE_FOR_fractuqqsi2 = 1268,
  CODE_FOR_fracthqsi2 = 1269,
  CODE_FOR_fractuhqsi2 = 1270,
  CODE_FOR_fracthasi2 = 1271,
  CODE_FOR_fractuhasi2 = 1272,
  CODE_FOR_fractsqsi2 = 1273,
  CODE_FOR_fractusqsi2 = 1274,
  CODE_FOR_fractsasi2 = 1275,
  CODE_FOR_fractusasi2 = 1276,
  CODE_FOR_fractdqsi2 = 1277,
  CODE_FOR_fractudqsi2 = 1278,
  CODE_FOR_fractdasi2 = 1279,
  CODE_FOR_fractudasi2 = 1280,
  CODE_FOR_fracttasi2 = 1281,
  CODE_FOR_fractutasi2 = 1282,
  CODE_FOR_fractqisi2 = 1283,
  CODE_FOR_fracthisi2 = 1284,
   CODE_FOR_fractsisi2 = CODE_FOR_nothing,
  CODE_FOR_fractdisi2 = 1285,
  CODE_FOR_fractqqdi2 = 1286,
  CODE_FOR_fractuqqdi2 = 1287,
  CODE_FOR_fracthqdi2 = 1288,
  CODE_FOR_fractuhqdi2 = 1289,
  CODE_FOR_fracthadi2 = 1290,
  CODE_FOR_fractuhadi2 = 1291,
  CODE_FOR_fractsqdi2 = 1292,
  CODE_FOR_fractusqdi2 = 1293,
  CODE_FOR_fractsadi2 = 1294,
  CODE_FOR_fractusadi2 = 1295,
  CODE_FOR_fractdqdi2 = 1296,
  CODE_FOR_fractudqdi2 = 1297,
  CODE_FOR_fractdadi2 = 1298,
  CODE_FOR_fractudadi2 = 1299,
  CODE_FOR_fracttadi2 = 1300,
  CODE_FOR_fractutadi2 = 1301,
  CODE_FOR_fractqidi2 = 1302,
  CODE_FOR_fracthidi2 = 1303,
  CODE_FOR_fractsidi2 = 1304,
   CODE_FOR_fractdidi2 = CODE_FOR_nothing,
   CODE_FOR_fractunsqqqq2 = CODE_FOR_nothing,
  CODE_FOR_fractunsuqqqq2 = 1685,
  CODE_FOR_fractunshqqq2 = 1686,
  CODE_FOR_fractunsuhqqq2 = 1687,
  CODE_FOR_fractunshaqq2 = 1688,
  CODE_FOR_fractunsuhaqq2 = 1689,
  CODE_FOR_fractunssqqq2 = 1690,
  CODE_FOR_fractunsusqqq2 = 1691,
  CODE_FOR_fractunssaqq2 = 1692,
  CODE_FOR_fractunsusaqq2 = 1693,
  CODE_FOR_fractunsdqqq2 = 1694,
  CODE_FOR_fractunsudqqq2 = 1695,
  CODE_FOR_fractunsdaqq2 = 1696,
  CODE_FOR_fractunsudaqq2 = 1697,
  CODE_FOR_fractunstaqq2 = 1698,
  CODE_FOR_fractunsutaqq2 = 1699,
  CODE_FOR_fractunsqiqq2 = 1700,
  CODE_FOR_fractunshiqq2 = 1701,
  CODE_FOR_fractunssiqq2 = 1702,
  CODE_FOR_fractunsdiqq2 = 1703,
  CODE_FOR_fractunsqquqq2 = 1704,
   CODE_FOR_fractunsuqquqq2 = CODE_FOR_nothing,
  CODE_FOR_fractunshquqq2 = 1705,
  CODE_FOR_fractunsuhquqq2 = 1706,
  CODE_FOR_fractunshauqq2 = 1707,
  CODE_FOR_fractunsuhauqq2 = 1708,
  CODE_FOR_fractunssquqq2 = 1709,
  CODE_FOR_fractunsusquqq2 = 1710,
  CODE_FOR_fractunssauqq2 = 1711,
  CODE_FOR_fractunsusauqq2 = 1712,
  CODE_FOR_fractunsdquqq2 = 1713,
  CODE_FOR_fractunsudquqq2 = 1714,
  CODE_FOR_fractunsdauqq2 = 1715,
  CODE_FOR_fractunsudauqq2 = 1716,
  CODE_FOR_fractunstauqq2 = 1717,
  CODE_FOR_fractunsutauqq2 = 1718,
  CODE_FOR_fractunsqiuqq2 = 1719,
  CODE_FOR_fractunshiuqq2 = 1720,
  CODE_FOR_fractunssiuqq2 = 1721,
  CODE_FOR_fractunsdiuqq2 = 1722,
  CODE_FOR_fractunsqqhq2 = 1723,
  CODE_FOR_fractunsuqqhq2 = 1724,
   CODE_FOR_fractunshqhq2 = CODE_FOR_nothing,
  CODE_FOR_fractunsuhqhq2 = 1725,
  CODE_FOR_fractunshahq2 = 1726,
  CODE_FOR_fractunsuhahq2 = 1727,
  CODE_FOR_fractunssqhq2 = 1728,
  CODE_FOR_fractunsusqhq2 = 1729,
  CODE_FOR_fractunssahq2 = 1730,
  CODE_FOR_fractunsusahq2 = 1731,
  CODE_FOR_fractunsdqhq2 = 1732,
  CODE_FOR_fractunsudqhq2 = 1733,
  CODE_FOR_fractunsdahq2 = 1734,
  CODE_FOR_fractunsudahq2 = 1735,
  CODE_FOR_fractunstahq2 = 1736,
  CODE_FOR_fractunsutahq2 = 1737,
  CODE_FOR_fractunsqihq2 = 1738,
  CODE_FOR_fractunshihq2 = 1739,
  CODE_FOR_fractunssihq2 = 1740,
  CODE_FOR_fractunsdihq2 = 1741,
  CODE_FOR_fractunsqquhq2 = 1742,
  CODE_FOR_fractunsuqquhq2 = 1743,
  CODE_FOR_fractunshquhq2 = 1744,
   CODE_FOR_fractunsuhquhq2 = CODE_FOR_nothing,
  CODE_FOR_fractunshauhq2 = 1745,
  CODE_FOR_fractunsuhauhq2 = 1746,
  CODE_FOR_fractunssquhq2 = 1747,
  CODE_FOR_fractunsusquhq2 = 1748,
  CODE_FOR_fractunssauhq2 = 1749,
  CODE_FOR_fractunsusauhq2 = 1750,
  CODE_FOR_fractunsdquhq2 = 1751,
  CODE_FOR_fractunsudquhq2 = 1752,
  CODE_FOR_fractunsdauhq2 = 1753,
  CODE_FOR_fractunsudauhq2 = 1754,
  CODE_FOR_fractunstauhq2 = 1755,
  CODE_FOR_fractunsutauhq2 = 1756,
  CODE_FOR_fractunsqiuhq2 = 1757,
  CODE_FOR_fractunshiuhq2 = 1758,
  CODE_FOR_fractunssiuhq2 = 1759,
  CODE_FOR_fractunsdiuhq2 = 1760,
  CODE_FOR_fractunsqqha2 = 1761,
  CODE_FOR_fractunsuqqha2 = 1762,
  CODE_FOR_fractunshqha2 = 1763,
  CODE_FOR_fractunsuhqha2 = 1764,
   CODE_FOR_fractunshaha2 = CODE_FOR_nothing,
  CODE_FOR_fractunsuhaha2 = 1765,
  CODE_FOR_fractunssqha2 = 1766,
  CODE_FOR_fractunsusqha2 = 1767,
  CODE_FOR_fractunssaha2 = 1768,
  CODE_FOR_fractunsusaha2 = 1769,
  CODE_FOR_fractunsdqha2 = 1770,
  CODE_FOR_fractunsudqha2 = 1771,
  CODE_FOR_fractunsdaha2 = 1772,
  CODE_FOR_fractunsudaha2 = 1773,
  CODE_FOR_fractunstaha2 = 1774,
  CODE_FOR_fractunsutaha2 = 1775,
  CODE_FOR_fractunsqiha2 = 1776,
  CODE_FOR_fractunshiha2 = 1777,
  CODE_FOR_fractunssiha2 = 1778,
  CODE_FOR_fractunsdiha2 = 1779,
  CODE_FOR_fractunsqquha2 = 1780,
  CODE_FOR_fractunsuqquha2 = 1781,
  CODE_FOR_fractunshquha2 = 1782,
  CODE_FOR_fractunsuhquha2 = 1783,
  CODE_FOR_fractunshauha2 = 1784,
   CODE_FOR_fractunsuhauha2 = CODE_FOR_nothing,
  CODE_FOR_fractunssquha2 = 1785,
  CODE_FOR_fractunsusquha2 = 1786,
  CODE_FOR_fractunssauha2 = 1787,
  CODE_FOR_fractunsusauha2 = 1788,
  CODE_FOR_fractunsdquha2 = 1789,
  CODE_FOR_fractunsudquha2 = 1790,
  CODE_FOR_fractunsdauha2 = 1791,
  CODE_FOR_fractunsudauha2 = 1792,
  CODE_FOR_fractunstauha2 = 1793,
  CODE_FOR_fractunsutauha2 = 1794,
  CODE_FOR_fractunsqiuha2 = 1795,
  CODE_FOR_fractunshiuha2 = 1796,
  CODE_FOR_fractunssiuha2 = 1797,
  CODE_FOR_fractunsdiuha2 = 1798,
  CODE_FOR_fractunsqqsq2 = 1799,
  CODE_FOR_fractunsuqqsq2 = 1800,
  CODE_FOR_fractunshqsq2 = 1801,
  CODE_FOR_fractunsuhqsq2 = 1802,
  CODE_FOR_fractunshasq2 = 1803,
  CODE_FOR_fractunsuhasq2 = 1804,
   CODE_FOR_fractunssqsq2 = CODE_FOR_nothing,
  CODE_FOR_fractunsusqsq2 = 1805,
  CODE_FOR_fractunssasq2 = 1806,
  CODE_FOR_fractunsusasq2 = 1807,
  CODE_FOR_fractunsdqsq2 = 1808,
  CODE_FOR_fractunsudqsq2 = 1809,
  CODE_FOR_fractunsdasq2 = 1810,
  CODE_FOR_fractunsudasq2 = 1811,
  CODE_FOR_fractunstasq2 = 1812,
  CODE_FOR_fractunsutasq2 = 1813,
  CODE_FOR_fractunsqisq2 = 1814,
  CODE_FOR_fractunshisq2 = 1815,
  CODE_FOR_fractunssisq2 = 1816,
  CODE_FOR_fractunsdisq2 = 1817,
  CODE_FOR_fractunsqqusq2 = 1818,
  CODE_FOR_fractunsuqqusq2 = 1819,
  CODE_FOR_fractunshqusq2 = 1820,
  CODE_FOR_fractunsuhqusq2 = 1821,
  CODE_FOR_fractunshausq2 = 1822,
  CODE_FOR_fractunsuhausq2 = 1823,
  CODE_FOR_fractunssqusq2 = 1824,
   CODE_FOR_fractunsusqusq2 = CODE_FOR_nothing,
  CODE_FOR_fractunssausq2 = 1825,
  CODE_FOR_fractunsusausq2 = 1826,
  CODE_FOR_fractunsdqusq2 = 1827,
  CODE_FOR_fractunsudqusq2 = 1828,
  CODE_FOR_fractunsdausq2 = 1829,
  CODE_FOR_fractunsudausq2 = 1830,
  CODE_FOR_fractunstausq2 = 1831,
  CODE_FOR_fractunsutausq2 = 1832,
  CODE_FOR_fractunsqiusq2 = 1833,
  CODE_FOR_fractunshiusq2 = 1834,
  CODE_FOR_fractunssiusq2 = 1835,
  CODE_FOR_fractunsdiusq2 = 1836,
  CODE_FOR_fractunsqqsa2 = 1837,
  CODE_FOR_fractunsuqqsa2 = 1838,
  CODE_FOR_fractunshqsa2 = 1839,
  CODE_FOR_fractunsuhqsa2 = 1840,
  CODE_FOR_fractunshasa2 = 1841,
  CODE_FOR_fractunsuhasa2 = 1842,
  CODE_FOR_fractunssqsa2 = 1843,
  CODE_FOR_fractunsusqsa2 = 1844,
   CODE_FOR_fractunssasa2 = CODE_FOR_nothing,
  CODE_FOR_fractunsusasa2 = 1845,
  CODE_FOR_fractunsdqsa2 = 1846,
  CODE_FOR_fractunsudqsa2 = 1847,
  CODE_FOR_fractunsdasa2 = 1848,
  CODE_FOR_fractunsudasa2 = 1849,
  CODE_FOR_fractunstasa2 = 1850,
  CODE_FOR_fractunsutasa2 = 1851,
  CODE_FOR_fractunsqisa2 = 1852,
  CODE_FOR_fractunshisa2 = 1853,
  CODE_FOR_fractunssisa2 = 1854,
  CODE_FOR_fractunsdisa2 = 1855,
  CODE_FOR_fractunsqqusa2 = 1856,
  CODE_FOR_fractunsuqqusa2 = 1857,
  CODE_FOR_fractunshqusa2 = 1858,
  CODE_FOR_fractunsuhqusa2 = 1859,
  CODE_FOR_fractunshausa2 = 1860,
  CODE_FOR_fractunsuhausa2 = 1861,
  CODE_FOR_fractunssqusa2 = 1862,
  CODE_FOR_fractunsusqusa2 = 1863,
  CODE_FOR_fractunssausa2 = 1864,
   CODE_FOR_fractunsusausa2 = CODE_FOR_nothing,
  CODE_FOR_fractunsdqusa2 = 1865,
  CODE_FOR_fractunsudqusa2 = 1866,
  CODE_FOR_fractunsdausa2 = 1867,
  CODE_FOR_fractunsudausa2 = 1868,
  CODE_FOR_fractunstausa2 = 1869,
  CODE_FOR_fractunsutausa2 = 1870,
  CODE_FOR_fractunsqiusa2 = 1871,
  CODE_FOR_fractunshiusa2 = 1872,
  CODE_FOR_fractunssiusa2 = 1873,
  CODE_FOR_fractunsdiusa2 = 1874,
  CODE_FOR_fractunsqqdq2 = 1875,
  CODE_FOR_fractunsuqqdq2 = 1876,
  CODE_FOR_fractunshqdq2 = 1877,
  CODE_FOR_fractunsuhqdq2 = 1878,
  CODE_FOR_fractunshadq2 = 1879,
  CODE_FOR_fractunsuhadq2 = 1880,
  CODE_FOR_fractunssqdq2 = 1881,
  CODE_FOR_fractunsusqdq2 = 1882,
  CODE_FOR_fractunssadq2 = 1883,
  CODE_FOR_fractunsusadq2 = 1884,
   CODE_FOR_fractunsdqdq2 = CODE_FOR_nothing,
  CODE_FOR_fractunsudqdq2 = 1885,
  CODE_FOR_fractunsdadq2 = 1886,
  CODE_FOR_fractunsudadq2 = 1887,
  CODE_FOR_fractunstadq2 = 1888,
  CODE_FOR_fractunsutadq2 = 1889,
  CODE_FOR_fractunsqidq2 = 1890,
  CODE_FOR_fractunshidq2 = 1891,
  CODE_FOR_fractunssidq2 = 1892,
  CODE_FOR_fractunsdidq2 = 1893,
  CODE_FOR_fractunsqqudq2 = 1894,
  CODE_FOR_fractunsuqqudq2 = 1895,
  CODE_FOR_fractunshqudq2 = 1896,
  CODE_FOR_fractunsuhqudq2 = 1897,
  CODE_FOR_fractunshaudq2 = 1898,
  CODE_FOR_fractunsuhaudq2 = 1899,
  CODE_FOR_fractunssqudq2 = 1900,
  CODE_FOR_fractunsusqudq2 = 1901,
  CODE_FOR_fractunssaudq2 = 1902,
  CODE_FOR_fractunsusaudq2 = 1903,
  CODE_FOR_fractunsdqudq2 = 1904,
   CODE_FOR_fractunsudqudq2 = CODE_FOR_nothing,
  CODE_FOR_fractunsdaudq2 = 1905,
  CODE_FOR_fractunsudaudq2 = 1906,
  CODE_FOR_fractunstaudq2 = 1907,
  CODE_FOR_fractunsutaudq2 = 1908,
  CODE_FOR_fractunsqiudq2 = 1909,
  CODE_FOR_fractunshiudq2 = 1910,
  CODE_FOR_fractunssiudq2 = 1911,
  CODE_FOR_fractunsdiudq2 = 1912,
  CODE_FOR_fractunsqqda2 = 1913,
  CODE_FOR_fractunsuqqda2 = 1914,
  CODE_FOR_fractunshqda2 = 1915,
  CODE_FOR_fractunsuhqda2 = 1916,
  CODE_FOR_fractunshada2 = 1917,
  CODE_FOR_fractunsuhada2 = 1918,
  CODE_FOR_fractunssqda2 = 1919,
  CODE_FOR_fractunsusqda2 = 1920,
  CODE_FOR_fractunssada2 = 1921,
  CODE_FOR_fractunsusada2 = 1922,
  CODE_FOR_fractunsdqda2 = 1923,
  CODE_FOR_fractunsudqda2 = 1924,
   CODE_FOR_fractunsdada2 = CODE_FOR_nothing,
  CODE_FOR_fractunsudada2 = 1925,
  CODE_FOR_fractunstada2 = 1926,
  CODE_FOR_fractunsutada2 = 1927,
  CODE_FOR_fractunsqida2 = 1928,
  CODE_FOR_fractunshida2 = 1929,
  CODE_FOR_fractunssida2 = 1930,
  CODE_FOR_fractunsdida2 = 1931,
  CODE_FOR_fractunsqquda2 = 1932,
  CODE_FOR_fractunsuqquda2 = 1933,
  CODE_FOR_fractunshquda2 = 1934,
  CODE_FOR_fractunsuhquda2 = 1935,
  CODE_FOR_fractunshauda2 = 1936,
  CODE_FOR_fractunsuhauda2 = 1937,
  CODE_FOR_fractunssquda2 = 1938,
  CODE_FOR_fractunsusquda2 = 1939,
  CODE_FOR_fractunssauda2 = 1940,
  CODE_FOR_fractunsusauda2 = 1941,
  CODE_FOR_fractunsdquda2 = 1942,
  CODE_FOR_fractunsudquda2 = 1943,
  CODE_FOR_fractunsdauda2 = 1944,
   CODE_FOR_fractunsudauda2 = CODE_FOR_nothing,
  CODE_FOR_fractunstauda2 = 1945,
  CODE_FOR_fractunsutauda2 = 1946,
  CODE_FOR_fractunsqiuda2 = 1947,
  CODE_FOR_fractunshiuda2 = 1948,
  CODE_FOR_fractunssiuda2 = 1949,
  CODE_FOR_fractunsdiuda2 = 1950,
  CODE_FOR_fractunsqqta2 = 1951,
  CODE_FOR_fractunsuqqta2 = 1952,
  CODE_FOR_fractunshqta2 = 1953,
  CODE_FOR_fractunsuhqta2 = 1954,
  CODE_FOR_fractunshata2 = 1955,
  CODE_FOR_fractunsuhata2 = 1956,
  CODE_FOR_fractunssqta2 = 1957,
  CODE_FOR_fractunsusqta2 = 1958,
  CODE_FOR_fractunssata2 = 1959,
  CODE_FOR_fractunsusata2 = 1960,
  CODE_FOR_fractunsdqta2 = 1961,
  CODE_FOR_fractunsudqta2 = 1962,
  CODE_FOR_fractunsdata2 = 1963,
  CODE_FOR_fractunsudata2 = 1964,
   CODE_FOR_fractunstata2 = CODE_FOR_nothing,
  CODE_FOR_fractunsutata2 = 1965,
  CODE_FOR_fractunsqita2 = 1966,
  CODE_FOR_fractunshita2 = 1967,
  CODE_FOR_fractunssita2 = 1968,
  CODE_FOR_fractunsdita2 = 1969,
  CODE_FOR_fractunsqquta2 = 1970,
  CODE_FOR_fractunsuqquta2 = 1971,
  CODE_FOR_fractunshquta2 = 1972,
  CODE_FOR_fractunsuhquta2 = 1973,
  CODE_FOR_fractunshauta2 = 1974,
  CODE_FOR_fractunsuhauta2 = 1975,
  CODE_FOR_fractunssquta2 = 1976,
  CODE_FOR_fractunsusquta2 = 1977,
  CODE_FOR_fractunssauta2 = 1978,
  CODE_FOR_fractunsusauta2 = 1979,
  CODE_FOR_fractunsdquta2 = 1980,
  CODE_FOR_fractunsudquta2 = 1981,
  CODE_FOR_fractunsdauta2 = 1982,
  CODE_FOR_fractunsudauta2 = 1983,
  CODE_FOR_fractunstauta2 = 1984,
   CODE_FOR_fractunsutauta2 = CODE_FOR_nothing,
  CODE_FOR_fractunsqiuta2 = 1985,
  CODE_FOR_fractunshiuta2 = 1986,
  CODE_FOR_fractunssiuta2 = 1987,
  CODE_FOR_fractunsdiuta2 = 1988,
  CODE_FOR_fractunsqqqi2 = 1989,
  CODE_FOR_fractunsuqqqi2 = 1990,
  CODE_FOR_fractunshqqi2 = 1991,
  CODE_FOR_fractunsuhqqi2 = 1992,
  CODE_FOR_fractunshaqi2 = 1993,
  CODE_FOR_fractunsuhaqi2 = 1994,
  CODE_FOR_fractunssqqi2 = 1995,
  CODE_FOR_fractunsusqqi2 = 1996,
  CODE_FOR_fractunssaqi2 = 1997,
  CODE_FOR_fractunsusaqi2 = 1998,
  CODE_FOR_fractunsdqqi2 = 1999,
  CODE_FOR_fractunsudqqi2 = 2000,
  CODE_FOR_fractunsdaqi2 = 2001,
  CODE_FOR_fractunsudaqi2 = 2002,
  CODE_FOR_fractunstaqi2 = 2003,
  CODE_FOR_fractunsutaqi2 = 2004,
   CODE_FOR_fractunsqiqi2 = CODE_FOR_nothing,
  CODE_FOR_fractunshiqi2 = 2005,
  CODE_FOR_fractunssiqi2 = 2006,
  CODE_FOR_fractunsdiqi2 = 2007,
  CODE_FOR_fractunsqqhi2 = 2008,
  CODE_FOR_fractunsuqqhi2 = 2009,
  CODE_FOR_fractunshqhi2 = 2010,
  CODE_FOR_fractunsuhqhi2 = 2011,
  CODE_FOR_fractunshahi2 = 2012,
  CODE_FOR_fractunsuhahi2 = 2013,
  CODE_FOR_fractunssqhi2 = 2014,
  CODE_FOR_fractunsusqhi2 = 2015,
  CODE_FOR_fractunssahi2 = 2016,
  CODE_FOR_fractunsusahi2 = 2017,
  CODE_FOR_fractunsdqhi2 = 2018,
  CODE_FOR_fractunsudqhi2 = 2019,
  CODE_FOR_fractunsdahi2 = 2020,
  CODE_FOR_fractunsudahi2 = 2021,
  CODE_FOR_fractunstahi2 = 2022,
  CODE_FOR_fractunsutahi2 = 2023,
  CODE_FOR_fractunsqihi2 = 2024,
   CODE_FOR_fractunshihi2 = CODE_FOR_nothing,
  CODE_FOR_fractunssihi2 = 2025,
  CODE_FOR_fractunsdihi2 = 2026,
  CODE_FOR_fractunsqqsi2 = 2027,
  CODE_FOR_fractunsuqqsi2 = 2028,
  CODE_FOR_fractunshqsi2 = 2029,
  CODE_FOR_fractunsuhqsi2 = 2030,
  CODE_FOR_fractunshasi2 = 2031,
  CODE_FOR_fractunsuhasi2 = 2032,
  CODE_FOR_fractunssqsi2 = 2033,
  CODE_FOR_fractunsusqsi2 = 2034,
  CODE_FOR_fractunssasi2 = 2035,
  CODE_FOR_fractunsusasi2 = 2036,
  CODE_FOR_fractunsdqsi2 = 2037,
  CODE_FOR_fractunsudqsi2 = 2038,
  CODE_FOR_fractunsdasi2 = 2039,
  CODE_FOR_fractunsudasi2 = 2040,
  CODE_FOR_fractunstasi2 = 2041,
  CODE_FOR_fractunsutasi2 = 2042,
  CODE_FOR_fractunsqisi2 = 2043,
  CODE_FOR_fractunshisi2 = 2044,
   CODE_FOR_fractunssisi2 = CODE_FOR_nothing,
  CODE_FOR_fractunsdisi2 = 2045,
  CODE_FOR_fractunsqqdi2 = 2046,
  CODE_FOR_fractunsuqqdi2 = 2047,
  CODE_FOR_fractunshqdi2 = 2048,
  CODE_FOR_fractunsuhqdi2 = 2049,
  CODE_FOR_fractunshadi2 = 2050,
  CODE_FOR_fractunsuhadi2 = 2051,
  CODE_FOR_fractunssqdi2 = 2052,
  CODE_FOR_fractunsusqdi2 = 2053,
  CODE_FOR_fractunssadi2 = 2054,
  CODE_FOR_fractunsusadi2 = 2055,
  CODE_FOR_fractunsdqdi2 = 2056,
  CODE_FOR_fractunsudqdi2 = 2057,
  CODE_FOR_fractunsdadi2 = 2058,
  CODE_FOR_fractunsudadi2 = 2059,
  CODE_FOR_fractunstadi2 = 2060,
  CODE_FOR_fractunsutadi2 = 2061,
  CODE_FOR_fractunsqidi2 = 2062,
  CODE_FOR_fractunshidi2 = 2063,
  CODE_FOR_fractunssidi2 = 2064,
   CODE_FOR_fractunsdidi2 = CODE_FOR_nothing,
  CODE_FOR_ssaddqq3 = 2445,
  CODE_FOR_sssubqq3 = 2446,
  CODE_FOR_ssaddhq3 = 2447,
  CODE_FOR_sssubhq3 = 2448,
  CODE_FOR_ssaddha3 = 2449,
  CODE_FOR_sssubha3 = 2450,
  CODE_FOR_ssaddsa3 = 2451,
  CODE_FOR_sssubsa3 = 2452,
  CODE_FOR_ssaddsq3 = 2453,
  CODE_FOR_sssubsq3 = 2454,
  CODE_FOR_usadduqq3 = 2465,
  CODE_FOR_ussubuqq3 = 2466,
  CODE_FOR_usadduhq3 = 2467,
  CODE_FOR_ussubuhq3 = 2468,
  CODE_FOR_usadduha3 = 2469,
  CODE_FOR_ussubuha3 = 2470,
  CODE_FOR_usaddusa3 = 2471,
  CODE_FOR_ussubusa3 = 2472,
  CODE_FOR_usaddusq3 = 2473,
  CODE_FOR_ussubusq3 = 2474,
  CODE_FOR_ssnegqq2 = 2485,
  CODE_FOR_ssabsqq2 = 2487,
  CODE_FOR_mulqq3_enh = 2505,
  CODE_FOR_muluqq3_enh = 2507,
  CODE_FOR_roundqq3_const = 2555,
  CODE_FOR_roundhq3_const = 2556,
  CODE_FOR_roundha3_const = 2557,
  CODE_FOR_roundsa3_const = 2558,
  CODE_FOR_roundsq3_const = 2559,
  CODE_FOR_rounduqq3_const = 2560,
  CODE_FOR_rounduhq3_const = 2561,
  CODE_FOR_rounduha3_const = 2562,
  CODE_FOR_roundusa3_const = 2563,
  CODE_FOR_roundusq3_const = 2564,
  CODE_FOR_adddi3_insn = 2595,
  CODE_FOR_adddq3_insn = 2596,
  CODE_FOR_addudq3_insn = 2597,
  CODE_FOR_addda3_insn = 2598,
  CODE_FOR_adduda3_insn = 2599,
  CODE_FOR_addta3_insn = 2600,
  CODE_FOR_adduta3_insn = 2601,
  CODE_FOR_adddi3_const8_insn = 2609,
  CODE_FOR_adddi3_const_insn = 2611,
  CODE_FOR_adddq3_const_insn = 2612,
  CODE_FOR_addudq3_const_insn = 2613,
  CODE_FOR_addda3_const_insn = 2614,
  CODE_FOR_adduda3_const_insn = 2615,
  CODE_FOR_addta3_const_insn = 2616,
  CODE_FOR_adduta3_const_insn = 2617,
  CODE_FOR_subdi3_insn = 2625,
  CODE_FOR_subdq3_insn = 2626,
  CODE_FOR_subudq3_insn = 2627,
  CODE_FOR_subda3_insn = 2628,
  CODE_FOR_subuda3_insn = 2629,
  CODE_FOR_subta3_insn = 2630,
  CODE_FOR_subuta3_insn = 2631,
  CODE_FOR_subdi3_const_insn = 2639,
  CODE_FOR_subdq3_const_insn = 2640,
  CODE_FOR_subudq3_const_insn = 2641,
  CODE_FOR_subda3_const_insn = 2642,
  CODE_FOR_subuda3_const_insn = 2643,
  CODE_FOR_subta3_const_insn = 2644,
  CODE_FOR_subuta3_const_insn = 2645,
  CODE_FOR_ssadddq3_insn = 2653,
  CODE_FOR_sssubdq3_insn = 2654,
  CODE_FOR_ssaddda3_insn = 2655,
  CODE_FOR_sssubda3_insn = 2656,
  CODE_FOR_ssaddta3_insn = 2657,
  CODE_FOR_sssubta3_insn = 2658,
  CODE_FOR_ssadddq3_const_insn = 2665,
  CODE_FOR_sssubdq3_const_insn = 2666,
  CODE_FOR_ssaddda3_const_insn = 2667,
  CODE_FOR_sssubda3_const_insn = 2668,
  CODE_FOR_ssaddta3_const_insn = 2669,
  CODE_FOR_sssubta3_const_insn = 2670,
  CODE_FOR_usaddudq3_insn = 2677,
  CODE_FOR_ussubudq3_insn = 2678,
  CODE_FOR_usadduda3_insn = 2679,
  CODE_FOR_ussubuda3_insn = 2680,
  CODE_FOR_usadduta3_insn = 2681,
  CODE_FOR_ussubuta3_insn = 2682,
  CODE_FOR_usaddudq3_const_insn = 2689,
  CODE_FOR_ussubudq3_const_insn = 2690,
  CODE_FOR_usadduda3_const_insn = 2691,
  CODE_FOR_ussubuda3_const_insn = 2692,
  CODE_FOR_usadduta3_const_insn = 2693,
  CODE_FOR_ussubuta3_const_insn = 2694,
  CODE_FOR_negdi2_insn = 2701,
  CODE_FOR_cbranch_di2_split = 2703,
  CODE_FOR_cbranch_dq2_split = 2704,
  CODE_FOR_cbranch_udq2_split = 2705,
  CODE_FOR_cbranch_da2_split = 2706,
  CODE_FOR_cbranch_uda2_split = 2707,
  CODE_FOR_cbranch_ta2_split = 2708,
  CODE_FOR_cbranch_uta2_split = 2709,
  CODE_FOR_compare_di2 = 2710,
  CODE_FOR_compare_dq2 = 2711,
  CODE_FOR_compare_udq2 = 2712,
  CODE_FOR_compare_da2 = 2713,
  CODE_FOR_compare_uda2 = 2714,
  CODE_FOR_compare_ta2 = 2715,
  CODE_FOR_compare_uta2 = 2716,
  CODE_FOR_cbranch_const8_di2_split = 2717,
  CODE_FOR_compare_const8_di2 = 2718,
  CODE_FOR_cbranch_const_di2_split = 2719,
  CODE_FOR_cbranch_const_dq2_split = 2720,
  CODE_FOR_cbranch_const_udq2_split = 2721,
  CODE_FOR_cbranch_const_da2_split = 2722,
  CODE_FOR_cbranch_const_uda2_split = 2723,
  CODE_FOR_cbranch_const_ta2_split = 2724,
  CODE_FOR_cbranch_const_uta2_split = 2725,
  CODE_FOR_compare_const_di2 = 2726,
  CODE_FOR_compare_const_dq2 = 2727,
  CODE_FOR_compare_const_udq2 = 2728,
  CODE_FOR_compare_const_da2 = 2729,
  CODE_FOR_compare_const_uda2 = 2730,
  CODE_FOR_compare_const_ta2 = 2731,
  CODE_FOR_compare_const_uta2 = 2732,
  CODE_FOR_ashldi3_insn = 2733,
  CODE_FOR_ashrdi3_insn = 2734,
  CODE_FOR_lshrdi3_insn = 2735,
  CODE_FOR_rotldi3_insn = 2736,
  CODE_FOR_ashldq3_insn = 2737,
  CODE_FOR_ashrdq3_insn = 2738,
  CODE_FOR_lshrdq3_insn = 2739,
  CODE_FOR_rotldq3_insn = 2740,
  CODE_FOR_ashludq3_insn = 2741,
  CODE_FOR_ashrudq3_insn = 2742,
  CODE_FOR_lshrudq3_insn = 2743,
  CODE_FOR_rotludq3_insn = 2744,
  CODE_FOR_ashlda3_insn = 2745,
  CODE_FOR_ashrda3_insn = 2746,
  CODE_FOR_lshrda3_insn = 2747,
  CODE_FOR_rotlda3_insn = 2748,
  CODE_FOR_ashluda3_insn = 2749,
  CODE_FOR_ashruda3_insn = 2750,
  CODE_FOR_lshruda3_insn = 2751,
  CODE_FOR_rotluda3_insn = 2752,
  CODE_FOR_ashlta3_insn = 2753,
  CODE_FOR_ashrta3_insn = 2754,
  CODE_FOR_lshrta3_insn = 2755,
  CODE_FOR_rotlta3_insn = 2756,
  CODE_FOR_ashluta3_insn = 2757,
  CODE_FOR_ashruta3_insn = 2758,
  CODE_FOR_lshruta3_insn = 2759,
  CODE_FOR_rotluta3_insn = 2760,
  CODE_FOR_mulsidi3_insn = 2789,
  CODE_FOR_umulsidi3_insn = 2790,
  CODE_FOR_nonlocal_goto_receiver = 2793,
  CODE_FOR_nonlocal_goto = 2794,
  CODE_FOR_pushcqi1 = 2795,
  CODE_FOR_pushhi1 = 2796,
  CODE_FOR_pushchi1 = 2797,
  CODE_FOR_pushha1 = 2798,
  CODE_FOR_pushuha1 = 2799,
  CODE_FOR_pushhq1 = 2800,
  CODE_FOR_pushuhq1 = 2801,
  CODE_FOR_pushsi1 = 2802,
  CODE_FOR_pushcsi1 = 2803,
  CODE_FOR_pushsa1 = 2804,
  CODE_FOR_pushusa1 = 2805,
  CODE_FOR_pushsq1 = 2806,
  CODE_FOR_pushusq1 = 2807,
  CODE_FOR_pushdi1 = 2808,
  CODE_FOR_pushcdi1 = 2809,
  CODE_FOR_pushda1 = 2810,
  CODE_FOR_pushuda1 = 2811,
  CODE_FOR_pushdq1 = 2812,
  CODE_FOR_pushudq1 = 2813,
  CODE_FOR_pushta1 = 2814,
  CODE_FOR_pushuta1 = 2815,
  CODE_FOR_pushsf1 = 2816,
  CODE_FOR_pushdf1 = 2817,
  CODE_FOR_pushsc1 = 2818,
  CODE_FOR_pushdc1 = 2819,
  CODE_FOR_pushpsi1 = 2820,
  CODE_FOR_loadqi_libgcc = 2821,
  CODE_FOR_loadqq_libgcc = 2822,
  CODE_FOR_loaduqq_libgcc = 2823,
  CODE_FOR_loadhi_libgcc = 2824,
  CODE_FOR_loadhq_libgcc = 2825,
  CODE_FOR_loaduhq_libgcc = 2826,
  CODE_FOR_loadha_libgcc = 2827,
  CODE_FOR_loaduha_libgcc = 2828,
  CODE_FOR_loadsi_libgcc = 2829,
  CODE_FOR_loadsq_libgcc = 2830,
  CODE_FOR_loadusq_libgcc = 2831,
  CODE_FOR_loadsa_libgcc = 2832,
  CODE_FOR_loadusa_libgcc = 2833,
  CODE_FOR_loadsf_libgcc = 2834,
  CODE_FOR_loadpsi_libgcc = 2835,
  CODE_FOR_movqi = 2836,
  CODE_FOR_movqq = 2837,
  CODE_FOR_movuqq = 2838,
  CODE_FOR_movhi = 2839,
  CODE_FOR_movhq = 2840,
  CODE_FOR_movuhq = 2841,
  CODE_FOR_movha = 2842,
  CODE_FOR_movuha = 2843,
  CODE_FOR_movsi = 2844,
  CODE_FOR_movsq = 2845,
  CODE_FOR_movusq = 2846,
  CODE_FOR_movsa = 2847,
  CODE_FOR_movusa = 2848,
  CODE_FOR_movsf = 2849,
  CODE_FOR_movpsi = 2850,
  CODE_FOR_cpymemhi = 2851,
  CODE_FOR_setmemhi = 2852,
  CODE_FOR_strlenhi = 2853,
  CODE_FOR_addhi3 = 2854,
  CODE_FOR_addhq3 = 2855,
  CODE_FOR_adduhq3 = 2856,
  CODE_FOR_addha3 = 2857,
  CODE_FOR_adduha3 = 2858,
  CODE_FOR_mulqi3 = 2859,
  CODE_FOR_mulqi3_call = 2860,
  CODE_FOR_mulhi3 = 2861,
  CODE_FOR_mulhi3_call = 2862,
  CODE_FOR_mulsi3 = 2863,
  CODE_FOR_muluqisi3 = 2864,
  CODE_FOR_muluhisi3 = 2865,
  CODE_FOR_mulsqisi3 = 2866,
  CODE_FOR_mulshisi3 = 2867,
  CODE_FOR_mulohisi3 = 2868,
  CODE_FOR_mulhisi3 = 2869,
  CODE_FOR_umulhisi3 = 2870,
  CODE_FOR_usmulhisi3 = 2871,
  CODE_FOR_smulhi3_highpart = 2872,
  CODE_FOR_umulhi3_highpart = 2873,
  CODE_FOR_mulpsi3 = 2874,
  CODE_FOR_mulsqipsi3 = 2875,
  CODE_FOR_rotlqi3 = 2876,
  CODE_FOR_rotlqi3_4 = 2877,
  CODE_FOR_rotlhi3 = 2878,
  CODE_FOR_rotlpsi3 = 2879,
  CODE_FOR_rotlsi3 = 2880,
  CODE_FOR_ashlqi3 = 2881,
  CODE_FOR_ashlqq3 = 2882,
  CODE_FOR_ashluqq3 = 2883,
  CODE_FOR_ashlpsi3 = 2884,
  CODE_FOR_lshrqi3 = 2885,
  CODE_FOR_lshrqq3 = 2886,
  CODE_FOR_lshruqq3 = 2887,
  CODE_FOR_gen_comparehi = 2888,
  CODE_FOR_gen_comparepsi = 2889,
  CODE_FOR_gen_comparesi = 2890,
  CODE_FOR_cbranchqi4 = 2891,
  CODE_FOR_cbranchqq4 = 2892,
  CODE_FOR_cbranchuqq4 = 2893,
  CODE_FOR_cbranchhi4 = 2894,
  CODE_FOR_cbranchsi4 = 2895,
  CODE_FOR_cbranchpsi4 = 2896,
  CODE_FOR_cbranchhq4 = 2897,
  CODE_FOR_cbranchuhq4 = 2898,
  CODE_FOR_cbranchha4 = 2899,
  CODE_FOR_cbranchuha4 = 2900,
  CODE_FOR_cbranchsq4 = 2901,
  CODE_FOR_cbranchusq4 = 2902,
  CODE_FOR_cbranchsa4 = 2903,
  CODE_FOR_cbranchusa4 = 2904,
  CODE_FOR_call = 2905,
  CODE_FOR_sibcall = 2906,
  CODE_FOR_call_value = 2907,
  CODE_FOR_sibcall_value = 2908,
  CODE_FOR_indirect_jump = 2909,
  CODE_FOR_casesi = 2910,
  CODE_FOR_enable_interrupt = 2927,
  CODE_FOR_disable_interrupt = 2928,
  CODE_FOR_gasisr = 2929,
  CODE_FOR_prologue = 2930,
  CODE_FOR_epilogue = 2931,
  CODE_FOR_sibcall_epilogue = 2932,
  CODE_FOR_flash_segment1 = 2933,
  CODE_FOR_flash_segment = 2934,
  CODE_FOR_parityhi2 = 2935,
  CODE_FOR_paritysi2 = 2936,
  CODE_FOR_popcounthi2 = 2937,
  CODE_FOR_popcountsi2 = 2938,
  CODE_FOR_clzhi2 = 2939,
  CODE_FOR_clzsi2 = 2940,
  CODE_FOR_ctzhi2 = 2941,
  CODE_FOR_ctzsi2 = 2942,
  CODE_FOR_ffshi2 = 2943,
  CODE_FOR_ffssi2 = 2944,
  CODE_FOR_bswapsi2 = 2945,
  CODE_FOR_nopv = 2946,
  CODE_FOR_sleep = 2947,
  CODE_FOR_wdr = 2948,
  CODE_FOR_fmul = 2949,
  CODE_FOR_fmuls = 2950,
  CODE_FOR_fmulsu = 2951,
  CODE_FOR_insv = 2952,
  CODE_FOR_gen_add_for_eq_qi = 2953,
  CODE_FOR_gen_add_for_ne_qi = 2954,
  CODE_FOR_gen_add_for_eq_hi = 2955,
  CODE_FOR_gen_add_for_ne_hi = 2956,
  CODE_FOR_gen_add_for_eq_psi = 2957,
  CODE_FOR_gen_add_for_ne_psi = 2958,
  CODE_FOR_gen_add_for_eq_si = 2959,
  CODE_FOR_gen_add_for_ne_si = 2960,
  CODE_FOR_extzv = 2961,
  CODE_FOR_usneguqq2 = 2962,
  CODE_FOR_usneguhq2 = 2963,
  CODE_FOR_usneguha2 = 2964,
  CODE_FOR_usnegusa2 = 2965,
  CODE_FOR_usnegusq2 = 2966,
  CODE_FOR_ssabshq2 = 2967,
  CODE_FOR_ssneghq2 = 2968,
  CODE_FOR_ssabsha2 = 2969,
  CODE_FOR_ssnegha2 = 2970,
  CODE_FOR_ssabssa2 = 2971,
  CODE_FOR_ssnegsa2 = 2972,
  CODE_FOR_ssabssq2 = 2973,
  CODE_FOR_ssnegsq2 = 2974,
  CODE_FOR_mulqq3 = 2975,
  CODE_FOR_muluqq3 = 2976,
  CODE_FOR_mulqq3_nomul = 2977,
  CODE_FOR_muluqq3_nomul = 2978,
  CODE_FOR_mulhq3 = 2979,
  CODE_FOR_muluhq3 = 2980,
  CODE_FOR_mulha3 = 2981,
  CODE_FOR_muluha3 = 2982,
  CODE_FOR_mulsa3 = 2983,
  CODE_FOR_mulusa3 = 2984,
  CODE_FOR_udivqq3 = 2985,
  CODE_FOR_divqq3 = 2986,
  CODE_FOR_udivuqq3 = 2987,
  CODE_FOR_divuqq3 = 2988,
  CODE_FOR_udivhq3 = 2989,
  CODE_FOR_divhq3 = 2990,
  CODE_FOR_udivuhq3 = 2991,
  CODE_FOR_divuhq3 = 2992,
  CODE_FOR_udivha3 = 2993,
  CODE_FOR_divha3 = 2994,
  CODE_FOR_udivuha3 = 2995,
  CODE_FOR_divuha3 = 2996,
  CODE_FOR_udivsa3 = 2997,
  CODE_FOR_divsa3 = 2998,
  CODE_FOR_udivusa3 = 2999,
  CODE_FOR_divusa3 = 3000,
  CODE_FOR_roundqq3 = 3001,
  CODE_FOR_roundhq3 = 3002,
  CODE_FOR_roundha3 = 3003,
  CODE_FOR_roundsa3 = 3004,
  CODE_FOR_roundsq3 = 3005,
  CODE_FOR_rounduqq3 = 3006,
  CODE_FOR_rounduhq3 = 3007,
  CODE_FOR_rounduha3 = 3008,
  CODE_FOR_roundusa3 = 3009,
  CODE_FOR_roundusq3 = 3010,
  CODE_FOR_adddi3 = 3011,
  CODE_FOR_adddq3 = 3012,
  CODE_FOR_addudq3 = 3013,
  CODE_FOR_addda3 = 3014,
  CODE_FOR_adduda3 = 3015,
  CODE_FOR_addta3 = 3016,
  CODE_FOR_adduta3 = 3017,
  CODE_FOR_subdi3 = 3018,
  CODE_FOR_subdq3 = 3019,
  CODE_FOR_subudq3 = 3020,
  CODE_FOR_subda3 = 3021,
  CODE_FOR_subuda3 = 3022,
  CODE_FOR_subta3 = 3023,
  CODE_FOR_subuta3 = 3024,
  CODE_FOR_ssadddq3 = 3025,
  CODE_FOR_sssubdq3 = 3026,
  CODE_FOR_ssaddda3 = 3027,
  CODE_FOR_sssubda3 = 3028,
  CODE_FOR_ssaddta3 = 3029,
  CODE_FOR_sssubta3 = 3030,
  CODE_FOR_usaddudq3 = 3031,
  CODE_FOR_ussubudq3 = 3032,
  CODE_FOR_usadduda3 = 3033,
  CODE_FOR_ussubuda3 = 3034,
  CODE_FOR_usadduta3 = 3035,
  CODE_FOR_ussubuta3 = 3036,
  CODE_FOR_negdi2 = 3037,
  CODE_FOR_conditional_jump = 3038,
  CODE_FOR_cbranchdi4 = 3039,
  CODE_FOR_cbranchdq4 = 3040,
  CODE_FOR_cbranchudq4 = 3041,
  CODE_FOR_cbranchda4 = 3042,
  CODE_FOR_cbranchuda4 = 3043,
  CODE_FOR_cbranchta4 = 3044,
  CODE_FOR_cbranchuta4 = 3045,
  CODE_FOR_ashldi3 = 3046,
  CODE_FOR_ashrdi3 = 3047,
  CODE_FOR_lshrdi3 = 3048,
  CODE_FOR_rotldi3 = 3049,
  CODE_FOR_ashldq3 = 3050,
  CODE_FOR_ashrdq3 = 3051,
  CODE_FOR_lshrdq3 = 3052,
  CODE_FOR_rotldq3 = 3053,
  CODE_FOR_ashludq3 = 3054,
  CODE_FOR_ashrudq3 = 3055,
  CODE_FOR_lshrudq3 = 3056,
  CODE_FOR_rotludq3 = 3057,
  CODE_FOR_ashlda3 = 3058,
  CODE_FOR_ashrda3 = 3059,
  CODE_FOR_lshrda3 = 3060,
  CODE_FOR_rotlda3 = 3061,
  CODE_FOR_ashluda3 = 3062,
  CODE_FOR_ashruda3 = 3063,
  CODE_FOR_lshruda3 = 3064,
  CODE_FOR_rotluda3 = 3065,
  CODE_FOR_ashlta3 = 3066,
  CODE_FOR_ashrta3 = 3067,
  CODE_FOR_lshrta3 = 3068,
  CODE_FOR_rotlta3 = 3069,
  CODE_FOR_ashluta3 = 3070,
  CODE_FOR_ashruta3 = 3071,
  CODE_FOR_lshruta3 = 3072,
  CODE_FOR_rotluta3 = 3073,
  CODE_FOR_mulsidi3 = 3074,
  CODE_FOR_umulsidi3 = 3075
};

const unsigned int NUM_INSN_CODES = 3076;
#endif /* GCC_INSN_CODES_H */
