/* Generated automatically by the program `genattr-common'
   from the machine description file `md'.  */

#ifndef GCC_INSN_ATTR_COMMON_H
#define GCC_INSN_ATTR_COMMON_H

enum attr_cc {CC_NONE, CC_SET_CZN, CC_SET_ZN, CC_SET_VZN, CC_SET_N, CC_COMPARE, CC_CLOBBER, CC_PLUS, CC_LDI};
enum attr_type {TYPE_BRANCH, TYPE_BRANCH1, TYPE_ARITH, TYPE_XCALL};
enum attr_adjust_len {ADJUST_LEN_OUT_BITOP, ADJUST_LEN_PLUS, ADJUST_LEN_ADDTO_SP, ADJUST_LEN_SEXT, ADJUST_LEN_TSTHI, ADJUST_LEN_TSTPSI, ADJUST_LEN_TSTSI, ADJUST_LEN_COMPARE, ADJUST_LEN_COMPARE64, ADJUST_LEN_CALL, ADJUST_LEN_MOV8, ADJUST_LEN_MOV16, ADJUST_LEN_MOV24, ADJUST_LEN_MOV32, ADJUST_LEN_RELOAD_IN16, ADJUST_LEN_RELOAD_IN24, ADJUST_LEN_RELOAD_IN32, ADJUST_LEN_UFRACT, ADJUST_LEN_SFRACT, ADJUST_LEN_ROUND, ADJUST_LEN_XLOAD, ADJUST_LEN_CPYMEM, ADJUST_LEN_ASHLQI, ADJUST_LEN_ASHRQI, ADJUST_LEN_LSHRQI, ADJUST_LEN_ASHLHI, ADJUST_LEN_ASHRHI, ADJUST_LEN_LSHRHI, ADJUST_LEN_ASHLSI, ADJUST_LEN_ASHRSI, ADJUST_LEN_LSHRSI, ADJUST_LEN_ASHLPSI, ADJUST_LEN_ASHRPSI, ADJUST_LEN_LSHRPSI, ADJUST_LEN_INSERT_BITS, ADJUST_LEN_INSV_NOTBIT, ADJUST_LEN_INSV_NOTBIT_0, ADJUST_LEN_INSV_NOTBIT_7, ADJUST_LEN_ADD_SET_ZN, ADJUST_LEN_CMP_UEXT, ADJUST_LEN_CMP_SEXT, ADJUST_LEN_NO};
enum attr_isa {ISA_MOV, ISA_MOVW, ISA_RJMP, ISA_JMP, ISA_IJMP, ISA_EIJMP, ISA_LPM, ISA_LPMX, ISA_ELPM, ISA_ELPMX, ISA_NO_XMEGA, ISA_XMEGA, ISA_NO_TINY, ISA_TINY, ISA_STANDARD};
#define DELAY_SLOTS 0

#endif /* GCC_INSN_ATTR_COMMON_H */
